summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmsqeedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmsqeedit.h')
-rw-r--r--kpovmodeler/pmsqeedit.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kpovmodeler/pmsqeedit.h b/kpovmodeler/pmsqeedit.h
index 99e87967..6cde9fc4 100644
--- a/kpovmodeler/pmsqeedit.h
+++ b/kpovmodeler/pmsqeedit.h
@@ -17,8 +17,8 @@
**************************************************************************/
-#ifndef PMSQEEDIT_H
-#define PMSQEEDIT_H
+#ifndef PMSTQEEDIT_H
+#define PMSTQEEDIT_H
#ifdef HAVE_CONFIG_H
#include <config.h>
@@ -35,12 +35,13 @@ class PMFloatEdit;
class PMSuperquadricEllipsoidEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMSuperquadricEllipsoidEdit with parent and name
*/
- PMSuperquadricEllipsoidEdit( TQWidget* parent, const char* name = 0 );
+ PMSuperquadricEllipsoidEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class PMFloatEdit;
public:
/**
- * Creates a PMSuperquadricEllipsoidEdit with parent and name
+ * Creates a PMSuperquadricEllipsoidEdit with tqparent and name
*/